# Data Lab Environment Manager

`Data Lab Environment Manager` is a tool that helps Seeq Data Lab users transition their Notebooks between different Python versions, manage projects, and handle Python packages effectively.


## Installation

```bash
pip install seeq_data_lab_env_mgr
```

## Usage

To access the tool:

```python
from seeq.data_lab_env_mgr import DataLabEnvMgr
DataLabEnvMgr()
```

For detailed documentation, please visit our [User Guide](https://support.seeq.com/kb/latest/cloud/user-guide-data-lab-environment-manager).